@@ -1,22 +1,22 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2014-2018, imageio contributors
+# Copyright (c) 2014-2020, imageio contributors
 # imageio is distributed under the terms of the (new) BSD License.
 
 # This docstring is used at the index of the documentation pages, and
 # gets inserted into a slightly larger description (in setup.py) for
 # the page on Pypi:
-""" 
+"""
 Imageio is a Python library that provides an easy interface to read and
 write a wide range of image data, including animated images, volumetric
-data, and scientific formats. It is cross-platform, runs on Python 2.7
-and 3.4+, and is easy to install.
+data, and scientific formats. It is cross-platform, runs on Python 3.5+,
+and is easy to install.
 
 Main website: http://imageio.github.io
 """
 
 # flake8: noqa
 
-__version__ = "2.5.0"
+__version__ = "2.8.0"
 
 # Load some bits from core
 from .core import FormatManager, RETURN_BYTES
