@@ -4,8 +4,8 @@
 
 from io import BytesIO
 import os
-import gc
 import sys
+import gc
 import time
 import threading
 
@@ -23,8 +23,6 @@ from imageio.core import get_remote_file, IS_PYPY
 test_dir = get_test_dir()
 
 
-if sys.version_info < (3,):
-    skip("imageio-ffmpeg is py3 only. It's 2019, come on.", allow_module_level=True)
 if os.getenv("TRAVIS_OS_NAME") == "windows":
     skip(
         "Skip this on the Travis Windows run for now, see #408", allow_module_level=True
@@ -103,6 +101,16 @@ def test_select():
     assert imageio.formats.search_read_format(core.Request(fname1, "rI")) is F
 
 
+def test_integer_reader_length():
+    # Avoid regression for #280
+    r = imageio.get_reader("imageio:cockatoo.mp4")
+    assert r.get_length() == float("inf")
+    assert isinstance(len(r), int)
+    assert len(r) == sys.maxsize
+    assert bool(r)
+    assert True if r else False
+
+
 def test_read_and_write():
 
     R = imageio.read(get_remote_file("images/cockatoo.mp4"), "ffmpeg")
@@ -246,7 +254,7 @@ def test_reader_more():
 
     # Now read beyond (simulate broken file)
     with raises(StopIteration):
-        R._read_frame()  # ffmpeg seems to have an extra frame, avbin not?
+        R._read_frame()  # ffmpeg seems to have an extra frame
         R._read_frame()
 
     # Set the image index to 0 and go again
